==> jboss-eap-6.4.6-src.zip: jboss-eap-6.4-src/testsuite/integration/multinode/src/test/java/org/jboss/as/test/multinode/transaction/TransactionalStatefulRemote.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.multinode.transaction;

import java.rmi.RemoteException;

/**
 * @author Stuart Douglas
 */
public interface TransactionalStatefulRemote {

    int transactionStatus() throws RemoteException;

    public Boolean getCommitSuceeded() throws RemoteException;

    public boolean isBeforeCompletion() throws RemoteException;

    public void resetStatus() throws RemoteException;

    public void sameTransaction(boolean first) throws RemoteException;

    void rollbackOnly() throws RemoteException;

    public void setRollbackOnlyBeforeCompletion(boolean rollbackOnlyInBeforeCompletion) throws RemoteException;

}

==> jboss-eap-7.0.7-src.zip: jboss-eap-7.0-src/testsuite/integration/multinode/src/test/java/org/jboss/as/test/multinode/transaction/TransactionalStatefulRemote.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.multinode.transaction;

import java.rmi.RemoteException;

/**
 * @author Stuart Douglas
 */
public interface TransactionalStatefulRemote {

    int transactionStatus() throws RemoteException;

    public Boolean getCommitSucceeded() throws RemoteException;

    public boolean isBeforeCompletion() throws RemoteException;

    public void resetStatus() throws RemoteException;

    public void sameTransaction(boolean first) throws RemoteException;

    void rollbackOnly() throws RemoteException;

    public void setRollbackOnlyBeforeCompletion(boolean rollbackOnlyInBeforeCompletion) throws RemoteException;

}
